<?php
/**
 * Elementor Widget
 * @package smartwp
 * @since 1.0.0
 */

namespace Elementor;
class smartwp_pricing extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'smartwp-pricing';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Pricing', 'smartwp' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-product-info';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'smartwp_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'pricing_section_top',
			[
				'label' => esc_html__( 'Pricing Section Top', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'ttitle',
			[
				'label'       => esc_html__( 'Section Top Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA                    ,
				'description' => esc_html__( 'enter title.', 'smartwp' ),
				'default'     => esc_html__('Time tested investment methods detailed Sales Just Few','smartwp')
			]
		);

		$this->add_control(
			'tcontent',
			[
				'label'       => esc_html__( 'Section Top Content', 'smartwp' ),
				'type'        => Controls_Manager::WYSIWYG,
				'description' => esc_html__( 'enter Content.', 'smartwp' ),
			]
		);	

		$this->add_control( 'top_items', [
			'label'       => esc_html__( 'Top Items', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'items' => esc_html__( 'Software is a generic term used to refer to application', 'smartwp' ),
				]
			],
			'fields'      => [

				[
					'name'        => 'toptext',
					'label'       => esc_html__( 'Top Text list', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
				],
				[
					'name'        => 'imagelist',
					'label'       => esc_html__( 'Top Image Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload Image', 'smartwp' )
				],

			],
			'title_field' => "{{name}}"
		] );

		$this->add_control(
	   		 'left-image',
	      	[
	          'label' => esc_html__( 'Top Left Image', 'smartwp' ),
	          'type'  => Controls_Manager::MEDIA,
				'dynamic' => [
				'active' => true,
			   ],
	    	]
	    );

		$this->end_controls_section();

		$this->start_controls_section(
			'pricing_section',
			[
				'label' => esc_html__( 'Pricing Section', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Section Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter title.', 'smartwp' ),
				'default'     => esc_html__('Our Best Pricing','smartwp')
			]
		);

		$this->add_control(
			'sub-title',
			[
				'label'       => esc_html__( 'Section Sub Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'enter Content.', 'smartwp' ),
			]
		);	

			$this->add_control( 'pricingtems', [
			'label'       => esc_html__( 'Pricing Items', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => [
				[
					'name'        => 'pheader',
					'label'       => esc_html__( 'Price Header', 'smartwp' ),
					'type'        => Controls_Manager::WYSIWYG,
					'description' => esc_html__( 'Enter Price Header', 'smartwp' )
				],
				[
					'name'        => 'pfeatures',
					'label'       => esc_html__( 'Enter Price Features', 'smartwp' ),
					'type'        => Controls_Manager::WYSIWYG,

				],				

			],
			'title_field' => "{{name}}"
		] );

		$this->end_controls_section();


		/*
		* pricing bottom content
		*/

		$this->start_controls_section(
			'pricing_section_bottom',
			[
				'label' => esc_html__( 'Pricing Section Bottom', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'btitle',
			[
				'label'       => esc_html__( 'Section Bottom Section Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA                    ,
				'description' => esc_html__( 'enter title.', 'smartwp' ),
				'default'     => esc_html__('Time tested investment methods detailed Sales Just Few','smartwp')
			]
		);

		$this->add_control(
			'bcontent',
			[
				'label'       => esc_html__( 'Section Bottom Content', 'smartwp' ),
				'type'        => Controls_Manager::WYSIWYG,
				'description' => esc_html__( 'enter Content.', 'smartwp' ),
			]
		);

		$this->add_control(
			'videoid',
			[
				'label'       => esc_html__( 'Section Bottom Video Id', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter Youtube video id.', 'smartwp' ),
				'default'	  =>'ScMzIvxBSi4'
			]
		);	


		$this->add_control(
	   		 'bimage',
	      	[
	          'label' => esc_html__( 'Bottom Image', 'smartwp' ),
	          'type'  => Controls_Manager::MEDIA,
				'dynamic' => [
				'active' => true,
			   ],
	    	]
	    );

		$this->end_controls_section();
	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		?>	
		<!-- Pricing Section Start -->
		<section class="pricing-section position-relative p-tb-120">
	        <!-- Pricing Top  -->
			<div class="pricing-top-area position-relative">
	            <!-- Left Wide Section -->
				<div class="top-wide-wrap">
					<div class="top-wide-bg">
						<img src="<?php echo esc_url( $settings['left-image']['url'] ); ?>" alt="alt">
					</div>
				</div>
				<div class="container">
					<div class="row">
						<div class="col-lg-6 offset-lg-6 col-md-12 col-12">
							<div class="pricing-top-right">
								<h3 class="fs-30 lh-45 m-b-30"><?php echo wp_kses_post( $settings['ttitle'] ); ?></h3>
								<?php echo wp_kses_post( $settings['tcontent'] ); ?>

								<ul class="right-list">
									<?php foreach( $settings['top_items'] as $item ) : ?>
										<li> <span class="right-list-img"><img src="<?php echo esc_url( $item['imagelist']['url'] ); ?>" alt="image"></span><?php echo esc_html( $item['toptext'] ); ?></li>
									 <?php endforeach; ?>
								</ul>
							</div>
						</div>
					</div>
				</div>
			</div>
	        <!-- Pricing Area -->
			<div class="pricing-area position-relative p-t-120" id="pricing">
				<div class="container">
					<!-- Section Title -->
					<div class="section-title m-b-60 text-center">
						<h3><?php echo esc_html( $settings['title'] ); ?></h3>
						<p><?php echo esc_html( $settings['sub-title'] ); ?></p>
					</div>
					<div class="row">
						<?php foreach( $settings['pricingtems'] as $item ) : ?>
							<div class="col-lg-4 col-md-6 col-12 offset-md-3 offset-lg-0">
								<!-- Single pricing boxes -->
								<div class="single-pricing-boxes">
									<div class="price-title text-center lh-45">
										<?php echo wp_kses_post( $item['pheader'] ); ?>
									</div>
									<div class="pricing-feature text-center p-tb-50">
										 <?php echo wp_kses_post( $item['pfeatures'] ); ?>
									</div>
								</div>
							</div>
						<?php endforeach; ?>
					</div>
				</div>
	             <!-- Pricing Bottom Wide -->
	            <div class="pricing-bottom-area position-relative m-t-120">
	                <!-- Left Wide Section -->
	                <div class="bottom-wide-wrap">
	                    <div class="bottom-wide-bg bg-img-c" style="background-image: url( <?php echo esc_url( $settings['bimage']['url'] ); ?> );">
	                        <div class="play-icon">
	                            <a class="popup-youtube" href="https://www.youtube.com/watch?v=<?php echo esc_attr( $settings['videoid'] ); ?>">
	                                <i class="fas fa-play"></i>
	                            </a>
	                        </div>
	                    </div>
	                </div>
	                <div class="container">
	                    <div class="row">
	                        <div class="col-lg-6">
	                            <div class="pricing-bottom-left">
	                                <h3 class="fs-30 lh-45 m-b-30"><?php echo wp_kses_post( $settings['btitle'] ); ?></h3>
	                                <?php echo wp_kses_post( $settings['bcontent'] ); ?>
	                            </div>
	                        </div>
	                    </div>
	                </div>
	            </div>
			</div>
		</section>

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new smartwp_pricing() );